Sortable

Struct Sortable 

pub struct Sortable {
    pub raw_object: Object,
    /* private fields */
}
Data related to the Sortable instance

When it is dropped, the list is made non-sortable again. This is required because callbacks could be called otherwise. If it is a problem for you, you can leak it, but be aware of the fact that it is a leak.

Fields

raw_object: Object

Raw Sortable JS object, should this crate not expose the necessary methods